==============================
Tasks Noise
==============================

EstimateNoiseInChannel
-------------------------

.. autoclass:: exorad.tasks.noiseHandler.EstimateNoiseInChannel
    :members:
    :undoc-members:
    :show-inheritance:

EstimateNoise
----------------

.. autoclass:: exorad.tasks.noiseHandler.EstimateNoise
    :members:
    :undoc-members:
    :show-inheritance:

